@@ -1,9 +1,9 @@
 import abc
 
-from stages.etl.etl import Etl
-from stages.evaluation.evaluation import Evaluation
-from stages.feature_engineering.feature_engineering import FeatureEngineering
-from stages.training.training import Training
+from nemuru_ml.stages.etl.etl import Etl
+from nemuru_ml.stages.evaluation.evaluation import Evaluation
+from nemuru_ml.stages.feature_engineering.feature_engineering import FeatureEngineering
+from nemuru_ml.stages.training.training import Training
 
 
 class Pipeline(abc.ABC):
