@@ -1,5 +1,5 @@
 import abc
-from common.model_registry import ModelRegistry
+from nemuru_ml.common.model_registry import ModelRegistry
 
 
 class Evaluation(abc.ABC):
@@ -22,5 +22,6 @@ class Evaluation(abc.ABC):
         raise NotImplementedError
 
     def update_model(self, model_uri: str, model_name: str):
+        self._model_registry.update(model_uri, model_name)
         if self.is_better_than_staging(model_uri, model_name):
             self._model_registry.update_staging(model_uri, model_name)
