@@ -1,6 +1,6 @@
 import abc
 import pandas as pd
-from common.logger import Logger
+from nemuru_ml.common.logger import Logger
 from typing import List
 
 
